@@ -7,13 +7,15 @@ import (
 	"github.com/urfave/cli/v2"
 )
 
-// Down is struct for running 'down' command.
+var _ Action = (*Down)(nil)
+
+// Down is a struct for running 'down' command.
 type Down struct {
 	build     *Build
 	autoBuild bool
 }
 
-// Run is main function for 'down' command.
+// Run is the main function for 'down' command.
 func (i *Down) Run(ctx context.Context) error {
 	if i.autoBuild {
 		if err := i.build.Run(ctx); err != nil {
@@ -26,14 +28,14 @@ func (i *Down) Run(ctx context.Context) error {
 		return err
 	}
 
-	return p.Destroy(ctx)
+	return p.Down(ctx)
 }
 
 // Cmd returns 'down' *cli.Command.
 func (i *Down) Cmd() *cli.Command {
 	return &cli.Command{
 		Name:   "down",
-		Usage:  "🔪 Delete all",
+		Usage:  "🔪 delete all",
 		Flags:  i.flags(),
 		Action: toCtx(i.Run),
 	}
