@@ -6,6 +6,7 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/helmwave/helmwave/pkg/template"
 	"github.com/helmwave/helmwave/tests"
 	"github.com/stretchr/testify/suite"
 	"github.com/urfave/cli/v2"
@@ -15,8 +16,18 @@ type StatusTestSuite struct {
 	suite.Suite
 }
 
-func (ts *StatusTestSuite) TestImplementsAction() {
-	ts.Require().Implements((*Action)(nil), &Status{})
+//nolintlint:paralleltest // can't parallel because of setenv
+func TestStatusTestSuite(t *testing.T) {
+	// t.Parallel()
+	suite.Run(t, new(StatusTestSuite))
+}
+
+func (ts *StatusTestSuite) TestCmd() {
+	s := &Status{}
+	cmd := s.Cmd()
+
+	ts.Require().NotNil(cmd)
+	ts.Require().NotEmpty(cmd.Name)
 }
 
 func (ts *StatusTestSuite) TestRun() {
@@ -27,7 +38,7 @@ func (ts *StatusTestSuite) TestRun() {
 		yml: &Yml{
 			tpl:       filepath.Join(tests.Root, "01_helmwave.yml.tpl"),
 			file:      filepath.Join(ts.T().TempDir(), "02_helmwave.yml"),
-			templater: "sprig",
+			templater: template.TemplaterSprig,
 		},
 	}
 
@@ -42,9 +53,3 @@ func (ts *StatusTestSuite) TestRun() {
 
 	ts.Require().NoError(s.Run(context.Background()))
 }
-
-//nolint:paralleltest // cannot parallel because of setenv
-func TestStatusTestSuite(t *testing.T) {
-	// t.Parallel()
-	suite.Run(t, new(StatusTestSuite))
-}
