@@ -1,13 +1,16 @@
 package kubedog
 
 import (
+	"bufio"
 	"bytes"
 	"errors"
 	"io"
 
 	log "github.com/sirupsen/logrus"
-	"gopkg.in/yaml.v3"
 	meta1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/runtime"
+	"k8s.io/apimachinery/pkg/util/yaml"
+	"k8s.io/client-go/kubernetes/scheme"
 )
 
 // Todo:  optimize?
@@ -15,9 +18,14 @@ import (
 // Resource is base structure for all k8s resources that have replicas.
 // Used to parse out replicas count.
 type Resource struct {
-	Spec             `yaml:"spec,omitempty" protobuf:"bytes,2,opt,name=spec"`
-	meta1.TypeMeta   `yaml:",inline"`
-	meta1.ObjectMeta `yaml:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
+	Spec             `yaml:"spec,omitempty" json:"spec,omitempty" protobuf:"bytes,2,opt,name=spec"`
+	meta1.TypeMeta   `yaml:",inline" json:",inline"`
+	meta1.ObjectMeta `yaml:"metadata,omitempty" json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
+}
+
+// DeepCopyObject is required to implement runtime.Object interface. It doesn't actually do anything, don't use.
+func (r *Resource) DeepCopyObject() runtime.Object {
+	return r
 }
 
 // Spec is spec structure with replicas. Only replicas count is used.
@@ -30,16 +38,25 @@ func Parse(yamlFile []byte) []Resource {
 	var a []Resource
 
 	r := bytes.NewReader(yamlFile)
-	dec := yaml.NewDecoder(r)
-
-	var t Resource
+	dec := yaml.NewYAMLReader(bufio.NewReader(r))
+	d := scheme.Codecs.UniversalDeserializer()
+	var doc []byte
 	var err error
-	for ; !errors.Is(err, io.EOF); err = dec.Decode(&t) {
+	for ; !errors.Is(err, io.EOF); doc, err = dec.Read() {
 		if err != nil {
 			log.WithError(err).Info("failed to parse resource manifest for kubedog")
 
 			continue
 		}
+
+		var t Resource
+		_, _, err := d.Decode(doc, nil, &t)
+		if err != nil {
+			log.WithError(err).Info("failed to parse resource manifest for kubedog")
+
+			continue
+		}
+
 		a = append(a, t)
 	}
 
