@@ -3,27 +3,17 @@ package plan
 import (
 	"github.com/helmwave/helmwave/pkg/helper"
 	"github.com/helmwave/helmwave/pkg/release"
-	"github.com/helmwave/helmwave/pkg/release/uniqname"
 	log "github.com/sirupsen/logrus"
+	"golang.org/x/exp/slices"
 )
 
 func buildReleases(tags []string, releases []release.Config, matchAll bool) ([]release.Config, error) {
-	if len(tags) == 0 {
-		return releases, nil
-	}
-
-	releasesMap := make(map[uniqname.UniqName]release.Config)
-
-	for _, r := range releases {
-		releasesMap[r.Uniq()] = r
-	}
-
 	plan := make([]release.Config, 0)
 
 	for _, r := range releases {
 		if checkTagInclusion(tags, r.Tags(), matchAll) {
 			var err error
-			plan, err = addToPlan(plan, r, releasesMap)
+			plan, err = addToPlan(plan, r, releases)
 			if err != nil {
 				log.WithError(err).Error("failed to build releases plan")
 
@@ -35,35 +25,56 @@ func buildReleases(tags []string, releases []release.Config, matchAll bool) ([]r
 	return plan, nil
 }
 
-//nolint:nestif
+//nolintlint:nestif
+//nolint:gocognit
 func addToPlan(plan []release.Config, rel release.Config,
-	releases map[uniqname.UniqName]release.Config,
+	releases []release.Config,
 ) ([]release.Config, error) {
-	if helper.In(rel, plan) {
-		return plan, nil
+	for _, r := range plan {
+		if r.Uniq() == rel.Uniq() {
+			if r != rel {
+				return nil, DuplicateReleasesError{uniq: rel.Uniq()}
+			} else {
+				return plan, nil
+			}
+		}
 	}
 
 	r := plan
 	r = append(r, rel)
 
-	for _, dep := range rel.DependsOn() {
-		if depRel, ok := releases[dep.Uniq()]; ok {
-			var err error
-			r, err = addToPlan(r, depRel, releases)
-			if err != nil {
-				return nil, err
+	deps := rel.DependsOn()
+
+	for i, dep := range deps {
+		found := false
+		l := rel.Logger().WithField("dependency", dep.Uniq())
+		l.Trace("searching for dependency")
+
+		for _, rel := range releases {
+			if rel.Uniq().Equal(dep.Uniq()) {
+				found = true
+				var err error
+				r, err = addToPlan(r, rel, releases)
+				if err != nil {
+					return nil, err
+				}
 			}
-		} else {
+		}
+
+		if !found {
 			if dep.Optional {
-				log.Warnf("cannot find dependency %q in available releases, skipping it", dep.Uniq())
+				l.Warn("can't find dependency in available releases, skipping")
+				deps = slices.Delete(deps, i, i+1)
 			} else {
-				rel.Logger().WithField("dependency", dep.Uniq()).Error("cannot find required dependency")
+				l.Error("can't find required dependency")
 
 				return nil, release.ErrDepFailed
 			}
 		}
 	}
 
+	rel.SetDependsOn(deps)
+
 	return r, nil
 }
 
@@ -77,6 +88,10 @@ func releaseNames(a []release.Config) (n []string) {
 
 // checkTagInclusion checks where any of release tags are included in target tags.
 func checkTagInclusion(targetTags, releaseTags []string, matchAll bool) bool {
+	if len(targetTags) == 0 {
+		return true
+	}
+
 	if matchAll {
 		return checkAllTagsInclusion(targetTags, releaseTags)
 	}
