@@ -7,21 +7,31 @@ import (
 	"github.com/helmwave/helmwave/pkg/release"
 	"github.com/helmwave/helmwave/pkg/repo"
 	log "github.com/sirupsen/logrus"
+	"helm.sh/helm/v3/pkg/registry"
 )
 
-func buildRepositories(m map[string][]*release.Config, in []*repo.Config) (out []*repo.Config, err error) {
+func (p *Plan) buildRepositories() (out []repo.Config, err error) {
+	return buildRepositories(
+		buildRepoMapTop(p.body.Releases),
+		p.body.Repositories,
+	)
+}
+
+func buildRepositories(m map[string][]release.Config, in []repo.Config) (out []repo.Config, err error) {
 	for rep, releases := range m {
 		rm := releaseNames(releases)
-		log.WithField(rep, rm).Debug("🗄 repo dependencies")
+
+		l := log.WithField("repository", rep)
+		l.WithField("releases", rm).Debug("🗄 found releases that depend on repository")
 
 		if repoIsLocal(rep) {
-			log.Infof("🗄 %q is local repo", rep)
+			l.Info("🗄 it is local repo")
 		} else if index, found := repo.IndexOfName(in, rep); found {
 			out = append(out, in[index])
-			log.Infof("🗄 %q has been added to the plan", rep)
+			l.Info("🗄 repo has been added to the plan")
 		} else {
-			log.WithField("releases", rm).
-				Warn("🗄 you will not be able to install this")
+			l.WithField("releases", rm).Warn("🗄 some releases depend on repository that is not defined")
+
 			return nil, errors.New("🗄 not found " + rep)
 		}
 	}
@@ -51,16 +61,19 @@ func buildRepositories(m map[string][]*release.Config, in []*repo.Config) (out [
 //
 // }
 
-func buildRepoMapTop(releases []*release.Config) map[string][]*release.Config {
-	m := make(map[string][]*release.Config)
+func buildRepoMapTop(releases []release.Config) map[string][]release.Config {
+	m := make(map[string][]release.Config)
 	for _, rel := range releases {
-		m[rel.Repo()] = append(m[rel.Repo()], rel)
+		// Added to map if is not OCI
+		if !registry.IsOCI(rel.Chart().Name) {
+			m[rel.Repo()] = append(m[rel.Repo()], rel)
+		}
 	}
 
 	return m
 }
 
-// // allRepos for releases
+// // allRepos for releases.
 // func allRepos(releases []*release.Config) ([]string, error) {
 //	var all []string
 //	for _, rel := range releases {
@@ -75,7 +88,7 @@ func buildRepoMapTop(releases []*release.Config) map[string][]*release.Config {
 //	return all, nil
 // }
 
-// repoIsLocal return true if repo is dir
+// repoIsLocal return true if repo is dir.
 func repoIsLocal(repoString string) bool {
 	if repoString == "" {
 		return true
