@@ -4,14 +4,14 @@ import (
 	"context"
 	"path/filepath"
 
-	"helm.sh/helm/v3/pkg/action"
-
 	"github.com/helmwave/helmwave/pkg/release"
 	"github.com/helmwave/helmwave/pkg/release/uniqname"
 	"github.com/helmwave/helmwave/pkg/repo"
 	"github.com/helmwave/helmwave/pkg/template"
 	log "github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/mock"
+	"helm.sh/helm/v3/pkg/action"
+	"helm.sh/helm/v3/pkg/chartutil"
 	helm "helm.sh/helm/v3/pkg/cli"
 	helmRelease "helm.sh/helm/v3/pkg/release"
 	helmRepo "helm.sh/helm/v3/pkg/repo"
@@ -21,8 +21,28 @@ type MockReleaseConfig struct {
 	mock.Mock
 }
 
-func (r *MockReleaseConfig) Uniq() uniqname.UniqName {
+func (r *MockReleaseConfig) SetChartName(s string) {
 	r.Called()
+}
+
+func (r *MockReleaseConfig) OfflineKubeVersion() *chartutil.KubeVersion {
+	r.Called()
+
+	v := &chartutil.KubeVersion{
+		Major:   "1",
+		Minor:   "22",
+		Version: "1.22.0",
+	}
+
+	return v
+}
+
+func (r *MockReleaseConfig) Uniq() uniqname.UniqName {
+	args := r.Called()
+
+	if len(args) > 0 {
+		return args.Get(0).(uniqname.UniqName)
+	}
 
 	u, _ := uniqname.Generate(r.Name(), r.Namespace())
 
@@ -78,8 +98,8 @@ func (r *MockReleaseConfig) Uninstall(context.Context) (*helmRelease.UninstallRe
 	return args.Get(0).(*helmRelease.UninstallReleaseResponse), args.Error(1)
 }
 
-func (r *MockReleaseConfig) Get() (*helmRelease.Release, error) {
-	args := r.Called()
+func (r *MockReleaseConfig) Get(version int) (*helmRelease.Release, error) {
+	args := r.Called(version)
 
 	return args.Get(0).(*helmRelease.Release), args.Error(1)
 }
@@ -90,7 +110,7 @@ func (r *MockReleaseConfig) List() (*helmRelease.Release, error) {
 	return args.Get(0).(*helmRelease.Release), args.Error(1)
 }
 
-func (r *MockReleaseConfig) Rollback(int) error {
+func (r *MockReleaseConfig) Rollback(context.Context, int) error {
 	return r.Called().Error(0)
 }
 
@@ -108,14 +128,18 @@ func (r *MockReleaseConfig) Namespace() string {
 	return r.Called().String(0)
 }
 
-func (r *MockReleaseConfig) Chart() release.Chart {
-	return r.Called().Get(0).(release.Chart)
+func (r *MockReleaseConfig) Chart() *release.Chart {
+	return r.Called().Get(0).(*release.Chart)
 }
 
 func (r *MockReleaseConfig) DependsOn() []*release.DependsOnReference {
 	return r.Called().Get(0).([]*release.DependsOnReference)
 }
 
+func (r *MockReleaseConfig) SetDependsOn(deps []*release.DependsOnReference) {
+	r.Called(deps)
+}
+
 func (r *MockReleaseConfig) Tags() []string {
 	return r.Called().Get(0).([]string)
 }
