@@ -14,6 +14,24 @@ import (
 // ErrValidateFailed is returned for failed values validation.
 var ErrValidateFailed = errors.New("validate failed")
 
+type DuplicateReleasesError struct {
+	uniq uniqname.UniqName
+}
+
+func (err DuplicateReleasesError) Error() string {
+	return fmt.Sprintf("release duplicate: %s", err.uniq.String())
+}
+
+//nolint:errorlint
+func (DuplicateReleasesError) Is(target error) bool {
+	switch target.(type) {
+	case DuplicateReleasesError, *DuplicateReleasesError:
+		return true
+	default:
+		return false
+	}
+}
+
 // ValidateValuesImport checks whether all values files exist.
 func (p *Plan) ValidateValuesImport() error {
 	f := false
@@ -37,7 +55,7 @@ func (p *Plan) ValidateValuesImport() error {
 	return ErrValidateFailed
 }
 
-// ValidateValuesBuild Dst now is public method.
+// ValidateValuesBuild Dst now is a public method.
 // Dst needs to marshal for export.
 // Also, dst needs to unmarshal for import from plan.
 func (p *Plan) ValidateValuesBuild() error {
@@ -53,8 +71,8 @@ func (p *Plan) ValidateValuesBuild() error {
 
 // Validate validates releases and repositories in plan.
 func (p *planBody) Validate() error {
-	if len(p.Releases) == 0 && len(p.Repositories) == 0 {
-		return errors.New("releases and repositories are empty")
+	if len(p.Releases) == 0 && len(p.Repositories) == 0 && len(p.Registries) == 0 {
+		return errors.New("releases, repositories and registries are empty")
 	}
 
 	if err := p.ValidateRegistries(); err != nil {
@@ -135,7 +153,7 @@ func (p *planBody) ValidateReleases() error {
 
 		a[r.Uniq()]++
 		if a[r.Uniq()] > 1 {
-			return errors.New("release duplicate: " + r.Uniq().String())
+			return DuplicateReleasesError{uniq: r.Uniq()}
 		}
 	}
 
